summaryrefslogtreecommitdiff
path: root/sd/source/ui/inc/tools/AsynchronousTask.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'sd/source/ui/inc/tools/AsynchronousTask.hxx')
-rwxr-xr-x[-rw-r--r--]sd/source/ui/inc/tools/AsynchronousTask.hxx4
1 files changed, 2 insertions, 2 deletions
diff --git a/sd/source/ui/inc/tools/AsynchronousTask.hxx b/sd/source/ui/inc/tools/AsynchronousTask.hxx
index f3135d3fcce7..28835560531c 100644..100755
--- a/sd/source/ui/inc/tools/AsynchronousTask.hxx
+++ b/sd/source/ui/inc/tools/AsynchronousTask.hxx
@@ -43,8 +43,8 @@ public:
*/
virtual void RunNextStep (void) = 0;
- /** Return <TRUE/> when there is at least one more step to execute.
- When the task has been executed completely then <FALSE/> is
+ /** Return <sal_True/> when there is at least one more step to execute.
+ When the task has been executed completely then <sal_False/> is
returned.
*/
virtual bool HasNextStep (void) = 0;